@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATION_SHADOW_H
-#define KDECORATION2_DECORATION_SHADOW_H
+#pragma once
 
 #include <kdecoration2/kdecoration2_export.h>
 
@@ -121,11 +120,9 @@ Q_SIGNALS:
 
 private:
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 }
 
 Q_DECLARE_METATYPE(KDecoration2::DecorationShadow *)
-
-#endif
